Crate upc_checker
upc_
checker
0.1.5
All Items
Crate Items
Structs
Enums
Crate
upc_
checker
Structs

UPC
Main UPC structure containing the base UPC code alonside it’s check digit. This is the core of the
upc_checker
library
Enums

UPCError
Error enum for the UPCs. This is responsable for the Error return on the
Result<T, E>
E (error) on the
UPC.check_upc()
method and commonly implaments errors when users use standards implamented by the
UPCStandard
wrongly.
UPCStandard
The impamentations on the widely-used UPC code standards are simple
i8
arrays with a defined length.